
/* Generated data (by glib-mkenums) */

#if !defined (__GCR_INSIDE_HEADER__) && !defined (GCR_COMPILATION)
#error "Only <gcr/gcr.h> can be included directly."
#endif

#ifndef __GCR_ENUM_TYPES_H__
#define __GCR_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "gcr-certificate-chain.h" */
GType gcr_certificate_chain_status_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_CERTIFICATE_CHAIN_STATUS (gcr_certificate_chain_status_get_type ())
GType gcr_certificate_chain_flags_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_CERTIFICATE_CHAIN_FLAGS (gcr_certificate_chain_flags_get_type ())

/* enumerations from "gcr-deprecated-base.h" */
GType gcr_importer_prompt_behavior_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_IMPORTER_PROMPT_BEHAVIOR (gcr_importer_prompt_behavior_get_type ())

/* enumerations from "gcr-types.h" */
GType gcr_data_error_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_DATA_ERROR (gcr_data_error_get_type ())
GType gcr_data_format_get_type (void) G_GNUC_CONST;
#define GCR_TYPE_DATA_FORMAT (gcr_data_format_get_type ())
G_END_DECLS

#endif /* __GCR_ENUM_TYPES_H__ */

/* Generated data ends here */

